CarouselItem class
Represents a single item in the ImagePreviewCarousel.
Can be either an image or a video.
Constructors
-
CarouselItem.image({required ImageProvider<
Object> ? image}) -
Create an item representing a static image.
const
-
CarouselItem.video({required String? videoUrl, ImageProvider<
Object> ? thumbnail}) -
Create an item representing a video.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
image
→ ImageProvider<
Object> ? -
The image provider for the main content (if type is CarouselItemType.image).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
thumbnail
→ ImageProvider<
Object> ? -
The thumbnail image provider.
final
- type → CarouselItemType
-
The type of this item (image or video).
final
- videoUrl → String?
-
The URL or path to the video (if type is CarouselItemType.video).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited