thumbnail property
The thumbnail image provider.
For videos, this is displayed in the gallery. For images, if this is null, the image is used as the thumbnail.
Implementation
final ImageProvider? thumbnail;
The thumbnail image provider.
For videos, this is displayed in the gallery. For images, if this is null, the image is used as the thumbnail.
final ImageProvider? thumbnail;